CaesarCipher class

A utility class for performing Caesar Cipher encryption and decryption.

The Caesar Cipher is one of the simplest and most widely known encryption techniques. It's a type of substitution cipher in which each letter in the plaintext is replaced by a letter some fixed number of positions down the alphabet.

Constructors

CaesarCipher()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt(String input, int key) String
Decrypts a given input string (ciphertext) using the Caesar Cipher algorithm.
encrypt(String input, {int key = 3}) String
Encrypts a given input string using the Caesar Cipher algorithm.