Fibonacci class

fibonacci_module.dart

A utility class for generating and confirming Fibonacci numbers.

Constructors

Fibonacci()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generateSequence(int n) List<BigInt>
Generates a Fibonacci sequence up to the specified number of terms.
isFibonacci(BigInt n) bool
Confirms if a given non-negative number n is a Fibonacci number.