NumberTheoryUtils class
A utility class for fundamental number theory operations, including Greatest Common Divisor (GCD) and Least Common Multiple (LCM).
This class provides static methods to compute these values efficiently for integer inputs.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited