RomanConversion class

Constructors

RomanConversion()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

toDecimal(String romanNumeral) int
Converts a Roman numeral string to its integer (decimal) representation.
toRoman(int n) String
Converts a given integer (decimal number) to its Roman numeral representation.