fahrenheitToKelvin static method

double fahrenheitToKelvin(
  1. double fahrenheit
)

Converts a temperature from Fahrenheit to Kelvin.

This conversion is done by first converting Fahrenheit to Celsius, and then Celsius to Kelvin.

Parameters:

  • fahrenheit: The temperature in degrees Fahrenheit.

Returns: The converted temperature in Kelvin.

Throws ArgumentError if the resulting Kelvin temperature would be below absolute zero (0 Kelvin).

Implementation

static double fahrenheitToKelvin(double fahrenheit) {
  final double celsius = fahrenheitToCelsius(fahrenheit);
  return celsiusToKelvin(celsius);
}