kelvinToFahrenheit static method
Converts a temperature from Kelvin to Fahrenheit.
This conversion is done by first converting Kelvin to Celsius, and then Celsius to Fahrenheit.
Parameters:
kelvin: The temperature in Kelvin.
Returns: The converted temperature in degrees Fahrenheit.
Throws ArgumentError if the input Kelvin temperature is negative, as temperatures below 0 Kelvin are physically impossible.
Implementation
static double kelvinToFahrenheit(double kelvin) {
final double celsius = kelvinToCelsius(kelvin);
return celsiusToFahrenheit(celsius);
}